@@ -1,16 +1,14 @@
+
+require 5;
 package Lingua::EN::Numbers::Ordinate;
-$Lingua::EN::Numbers::Ordinate::VERSION = '1.04_02'; # TRIAL
-
-$Lingua::EN::Numbers::Ordinate::VERSION = '1.0402';# ABSTRACT: go from cardinal number (3) to ordinal ("3rd")
-
-use 5.006;
 use strict;
-use warnings;
+# Time-stamp: "2004-12-29 19:06:20 AST"
+use vars qw(@ISA @EXPORT @EXPORT_OK $VERSION);
 require Exporter;
-
-our @ISA        = qw/ Exporter  /;
-our @EXPORT     = qw/ ordinate  /;
-our @EXPORT_OK  = qw/ ordsuf th /;
+@ISA = ('Exporter');
+@EXPORT = ('ordinate');
+@EXPORT_OK = ('ordsuf', 'th');
+$VERSION = "1.02";
 
 ###########################################################################
 
@@ -135,18 +133,6 @@ Damian Conway's I<Object Oriented Perl> from Manning Press.
 
 Kinda makes you like C<th(3)>, doesn't it?
 
-=head1 SEE ALSO
-
-L<Lingua::EN::Inflect> provides an C<ORD> function,
-which returns the ordinal form of a cardinal number.
-
-L<Lingua::EN::Number::IsOrdinal> provides an C<is_ordinal>
-function, which returns true if passed an ordinal number.
-
-=head1 REPOSITORY
-
-L<https://github.com/neilb/Lingua-EN-Numbers-Ordinate>
-
 =head1 COPYRIGHT
 
 Copyright (c) 2000 Sean M. Burke.  All rights reserved.
@@ -163,10 +149,10 @@ Sean M. Burke C<sburke@cpan.org>
 ###########################################################################
 
 sub ordsuf ($) {
-  return 'th' if not(defined($_[0])) or $_[0] !~ /^-?[0-9]+$/;
+  return 'th' if not(defined($_[0])) or not( 0 + $_[0] );
    # 'th' for undef, 0, or anything non-number.
   my $n = abs($_[0]);  # Throw away the sign.
-
+  return 'th' unless $n == int($n); # Best possible, I guess.
   $n %= 100;
   return 'th' if $n == 11 or $n == 12 or $n == 13;
   $n %= 10;
@@ -181,7 +167,6 @@ sub ordinate ($) {
   return $i . ordsuf($i);
 }
 
-no warnings 'all';
 *th = \&ordinate; # correctly copies the prototype, too.
 
 ###########################################################################
